@@ -145,6 +145,16 @@
 		state = NJB_PL_CHTRACKS;
 }
 
+- (void)deleteTrackWithID:(unsigned)trackID
+{
+  MyItem *item = [tracks itemWithID:trackID];
+  if (item != nil)
+    [tracks removeObject:item];
+
+  if (state != NJB_PL_NEW)
+  state = NJB_PL_CHTRACKS;
+}
+
 /* replaces the Tracks containing just IDs into full Track objects
  * from allTracks
  */
