@@ -5,20 +5,7 @@
 //  Created by Chris Drew on Tue Nov 12 2002.
 //  Copyright (c) 2002 __MyCompanyName__. All rights reserved.
 //
-#ifdef __APPLE__
 #import "TagAPI.h"
-#else
-#include "TagAPI.h"
-
-#include <Foundation/NSArray.h>
-#include <Foundation/NSBundle.h>
-#include <Foundation/NSDictionary.h>
-#include <Foundation/NSAutoreleasePool.h>
-#include <Foundation/NSString.h>
-#include <Foundation/NSValue.h>
-
-
-#endif
 
 @implementation TagAPI
 -(void)releaseAttributes
