@@ -5,17 +5,8 @@
 //  Created by Chris Drew on Thu Jan 16 2003.
 //  Copyright (c) 2003 __MyCompanyName__. All rights reserved.
 //
-
-#ifdef __APPLE__
 #import "V24FrameSet.h"
 #import "zlib.h"
-#else
-#include "V24FrameSet.h"
-#include "zlib.h"
-
-#include <Foundation/NSArray.h>
-#include <Foundation/NSData.h>
-#endif
 
 @implementation V24FrameSet
 -(id)init:(NSMutableData *)Frames version:(int)Minor validFrameSet:(NSDictionary *)FrameSet  frameSet:(NSMutableDictionary *)frameSet offset:(int)Offset taglength:(unsigned int)totalLength
