@@ -6,18 +6,7 @@
 //  Copyright (c) 2002 __MyCompanyName__. All rights reserved.
 //
 
-#ifdef __APPPLE__
 #import "id3V1Tag.h"
-#else
-#include "id3V1Tag.h"
-
-#include <Foundation/NSFileHandle.h>
-#include <Foundation/NSData.h>
-#include <Foundation/NSString.h>
-#include <Foundation/NSValue.h>
-#include <Foundation/NSCharacterSet.h>
-
-#endif
 
 // Constants for defining size and location of id3v1 tags with in a file
 #define id3TagLength	128
